@@ -21,12 +21,14 @@
 LKrig.MRF.precision <-
 function(mx,my, a.wght, edge=TRUE) {
   m<- mx*my
-  kappa2<- a.wght-4
+  if( length(a.wght)==1){
+    a.wght<- rep( a.wght,m)}
+  kappa2<-(a.wght-4)
   da<- as.integer( c(m,m))
   I<- as.integer(rep(1:mx,my))
   J<- as.integer(rep((1:my), rep( mx,my)))
 # contents of sparse matrix organize as 5 column matrix
-  ra<- cbind(rep( 4+kappa2, m), matrix( -1,m, 4))
+  ra<- cbind( 4+kappa2, matrix( -1,m, 4))
 #  Note: if  a.wght depends on lattice position
 # pass a.wght  as a matrix and use  ra<- as.numeric(c( ra,rep( c(a.wght), 4)))
 #  order is  center   top, bottom, left right
@@ -38,24 +40,26 @@ function(mx,my, a.wght, edge=TRUE) {
           I    + (J-2)*mx,
           I    +   (J)*mx )
  # fix up boundaries
+ # reformat kappa2 so that it is easier to index edges
+     kappa2<- matrix( kappa2, mx,my)
      if(edge){
        # the corners: fill each separately for clarity
        # corner.indices<- c( 1, mx, 1 + (my-1)*mx, mx*my)
        # upper left, lower left, upper right lower right
-       ra[1,] <-             c(1 + kappa2/4,  NA, -.5, NA, -.5)
-       ra[mx,]<-             c(1 + kappa2/4, -.5,  NA, NA, -.5)
-       ra[1 + (my-1)*mx,]<-  c(1 + kappa2/4,  NA, -.5, -.5,  NA)
-       ra[mx*my,]<-          c(1 + kappa2/4, -.5,  NA, -.5,  NA)
+       ra[1,] <-             c(1 + kappa2[1,1]/4,  NA, -.5, NA, -.5)
+       ra[mx,]<-             c(1 + kappa2[mx,1]/4, -.5,  NA, NA, -.5)
+       ra[1 + (my-1)*mx,]<-  c(1 + kappa2[1,my]/4,  NA, -.5, -.5,  NA)
+       ra[mx*my,]<-          c(1 + kappa2[mx,my]/4, -.5,  NA, -.5,  NA)
        # edges
        for( j in 2:(my-1)){
        # top row  then bottom row 
-         ra[ 1+ (j-1)*mx,]<-      c( 2 + kappa2/2, NA, -1, -.5, -.5)
-         ra[ mx + (j-1)*mx,]<-    c( 2 + kappa2/2, -1, NA, -.5, -.5)
+         ra[ 1+ (j-1)*mx,]<-      c( 2 + kappa2[1,j]/2, NA, -1, -.5, -.5)
+         ra[ mx + (j-1)*mx,]<-    c( 2 + kappa2[mx,j]/2, -1, NA, -.5, -.5)
         }
         for( i in 2:(mx-1)){
        # left side   then right
-          ra[ i , ]<-            c( 2 + kappa2/2, -.5, -.5, NA,  -1)
-          ra[ i + (my-1)*mx, ]<- c( 2 + kappa2/2, -.5, -.5, -1,  NA)
+          ra[ i , ]<-            c( 2 + kappa2[i,1]/2, -.5, -.5, NA,  -1)
+          ra[ i + (my-1)*mx, ]<- c( 2 + kappa2[i,my]/2, -.5, -.5, -1,  NA)
         }
      }
 # find all cases that are in lattice  
