@@ -39,25 +39,17 @@ function( x1, x2=NULL, LKinfo, C=NA, marginal=FALSE){
   }
     if (marginal){
       if( !is.null(x2)){
-      stop("x2 should not be passed to find marginal variance")}
-      if(LKinfo$normalize){
- # components all have marginal variance of one so the
- # sum is due to different alpha's the marginal variance for each level.
-        marginal.variance=  sum( LKinfo$alpha) # changed alpha
+        stop("x2 should not be passed to find marginal variance")}
+        PHI<- LKrig.basis( x1,LKinfo)
+#        Qc<-  chol( LKrig.precision(LKinfo) )
+#        A <- forwardsolve(Qc, transpose = TRUE, t(PHI), upper.tri = TRUE)
+#        test.variance<- c(colSums( A**2))
+        marginal.variance<- LKrig.quadraticform( LKrig.precision(LKinfo), PHI) 
         if( LKinfo$scale.basis){
- # add in additional scaling if part of covariance model         
-           marginal.variance*predict(LKinfo$rho.object, x1) }
-        else{
-           return(rep( marginal.variance, nrow(x1)))}
-      }
-      else{ 
-# without implicit normalization just find the marginal variances directly        
-        if( LKinfo$scale.basis){
-          stop("Can not scale an unnormalized basis")}
-      Qc<-  chol( LKrig.precision(LKinfo) )
-      PHI<- LKrig.basis( x1,LKinfo)
-      A <- forwardsolve(Qc, transpose = TRUE, t(PHI), upper.tri = TRUE)
-      return( c(colSums( A**2))) }
-    }
+# add in additional scaling if part of covariance model         
+           marginal.variance<- marginal.variance*predict(LKinfo$rho.object, x1) }
+        return( marginal.variance)
+   }
+# should not get here. 
 }
 
